@@ -75,6 +75,10 @@ struct_blit_meta = Struct(
         'description' / PaddedString(129, 'ascii'),
         'version' / PaddedString(17, 'ascii'),
         'author' / PaddedString(17, 'ascii'),
+        Const(b'BLITTYPE'),
+        'category' / PaddedString(17, 'ascii'),
+        'url' / PaddedString(129, 'ascii'),
+        'filetypes' / PrefixedArray(Int8ul, PaddedString(5, 'ascii')),
         'icon' / struct_blit_image,
         'splash' / struct_blit_image
     ))
@@ -89,6 +93,10 @@ struct_blit_meta_standalone = Struct(
         'description' / PaddedString(129, 'ascii'),
         'version' / PaddedString(17, 'ascii'),
         'author' / PaddedString(17, 'ascii'),
+        Const(b'BLITTYPE'),
+        'category' / PaddedString(17, 'ascii'),
+        'url' / PaddedString(129, 'ascii'),
+        'filetypes' / PrefixedArray(Int8ul, PaddedString(5, 'ascii')),
         'icon' / struct_blit_image,
         'splash' / struct_blit_image
     ))
